#
# spec file for package cups-filters
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Summary:        OpenPrinting CUPS filters, backends, and cups-browsed
# See also http://www.linuxfoundation.org/collaborate/workgroups/openprinting/pdf_as_standard_print_job_format
License:        GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-only AND MIT
Group:          Hardware/Printing
Url:            http://www.linuxfoundation.org/collaborate/workgroups/openprinting/cups-filters
# For a breakdown of the licensing, see COPYING file
# GPLv2:   filters: commandto*, imagetoraster, pdftops, rasterto*,
#                   imagetopdf, pstopdf, texttopdf
#         backends: parallel, serial
# GPLv2+:  filters: textonly, texttops, imagetops
# GPLv3:   filters: bannertopdf
# MIT:     filters: pdftoijs, pdftoopvp, pdftopdf, pdftoraster
Name:           cups-filters
# Normal version for official cups-filters releases is the upstream version (e.g. "Version: 1.0.49").
# For a current tarball cups-filters-1.0-yyyymmdd.tar.gz (e.g. cups-filters-1.0-20140326.tar.gz)
# the current tarball's date is added to the version to ensure a strictly increasing sequence
# "last version" < "current version" < "next version" e.g. "1.0.49" < "1.0.49.20140326" < "1.0.50"
# to verify this run: zypper vcmp 'last version' 'current version'
#       and also run: zypper vcmp 'next version' 'current version'
# e.g. zypper vcmp '1.0.49' '1.0.49.20140326' -> 1.0.49 is older than 1.0.49.20140326
#  and zypper vcmp '1.0.50' '1.0.49.20140326' -> 1.0.50 is newer than 1.0.49.20140326
Version:        1.20.3
Release:        lp150.2.6.1
Source0:        http://www.openprinting.org/download/cups-filters/cups-filters-%{version}.tar.xz
# Upstream fix for https://bugs.linuxfoundation.org/show_bug.cgi?id=1421
# in https://github.com/OpenPrinting/cups-filters/commit/6db3b08d3b20332b1525b8dd1a47950381b8f637
# dowloaded via
# wget -O fix_upstream_bug_1421.patch https://github.com/OpenPrinting/cups-filters/commit/6db3b08d3b20332b1525b8dd1a47950381b8f637.patch
# and then removed the changes of the NEWS file from that patch because
# the NEWS changes do not apply on the sources of the pristine 1.20.0 release:
# Patch100 fix_upstream_bug_1421.patch is fixed in the cups-filters 1.20.1 sources.
# Since cups-filters version 1.0.42 foomatic-rip is also provided by cups-filters.
# The foomatic-rip version that is provided by cups-filters is not specified in the cups-filters sources
# but on http://www.openprinting.org/download/foomatic/ the foomatic-filters-4.0-current.tar.gz
# dated 27-Mar-2014 (i.e. from today as of this writing) contains a VERSION.full file that reads "4.0.17.256"
# so that foomatic_rip_version (macro name can be only alphanumeric and '_' i.e. "foomatic-rip_version" does not work)
# is defined here accordingly but with one more additional trailing number '.1' to ensure that
# the sub-package cups-filters-foomatic-rip (see below) conflicts with any foomatic-filters package:
#   zypper vcmp '4.0.17.256' '4.0.17.256.1' -> 4.0.17.256 is older than 4.0.17.256.1
#   zypper vcmp '4.0.17.257' '4.0.17.256.1' -> 4.0.17.257 is newer than 4.0.17.256.1
Patch7:         cups-filters-297cc2de-gs-9.27.patch
# Since ghsotscript 9.27 the internal and undocumented "pdfdict" is gone, switch over to "runpdfbegin"
Patch8:         cups-filters-f0e1fc43.patch
# Backport from V1.22.2 due bug boo#1128167 -- "No destination host name supplied by cups-browsed"
# occurs if "LocalQueueNamingRemoteCUPS RemoteName" is set in cups-browsed.conf
%define foomatic_rip_version 4.0.17.256.1
# Support for cups154 in the SLE12 legacy module is abandoned (by default SLE12 has CUPS 1.7.5)
# because newer cups-filters versions use stuff that is provided since CUPS > 1.5.4 so that it does
# no longer build with CUPS 1.5.4 so that cups-filters does not work with CUPS 1.5.4:
BuildRequires:  cups-devel > 1.5.4
Requires:       cups > 1.5.4
BuildRequires:  pkgconfig
# pdftopdf
BuildRequires:  qpdf-devel
# pdftops
BuildRequires:  poppler-tools
# pdftoijs, pdftoopvp, pdftoraster
BuildRequires:  ghostscript-mini-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libpoppler-cpp0
BuildRequires:  libpoppler-devel
BuildRequires:  libpoppler-glib-devel
BuildRequires:  libtiff-devel
BuildRequires:  zlib-devel
# libijs
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  liblcms2-devel
# braille embossers
BuildRequires:  liblouis-devel
# Make sure we get postscriptdriver tags.
# suse_version >= 1330 means "after any SLE12 service pack and after any Leap 42.x"
# see https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
# and cf. cups.spec where the same test is used:
%if 0%{?suse_version} >= 1330
BuildRequires:  python3-cups
%else
BuildRequires:  python-cups
%endif
# cups-browsed
# "BuildRequires libavahi-devel" is insufficient
# (build fails at configure "checking for AVAHI_GLIB")
# "BuildRequires libavahi-gobject-devel" is too much
# (libavahi-gobject-devel requires libavahi-glib-devel and libavahi-devel)
# "BuildRequires libavahi-glib-devel" is sufficient
# (libavahi-glib-devel requires libavahi-devel)
BuildRequires:  libavahi-glib-devel
# autogen.sh
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  libtool
BuildRequires:  systemd
BuildRequires:  xz
%systemd_requires
# test requires
BuildRequires:  dejavu-fonts
# Conflict with CUPS < 1.6 because up to CUPS 1.5.4
# the following files are provided by the cups binary RPM package
# /usr/lib/cups/filter/commandtoescpx
# /usr/lib/cups/filter/commandtopclx
# /usr/lib/cups/filter/imagetops
# /usr/lib/cups/filter/imagetoraster
# /usr/lib/cups/filter/pdftops
# /usr/lib/cups/filter/rastertoescpx
# /usr/lib/cups/filter/rastertopclx
# /usr/lib/cups/filter/texttops
# /usr/lib/cups/backend/parallel
# /usr/lib/cups/backend/serial
# and the following files are provided by the cups-devel package
# /usr/share/cups/ppdc/escp.h
# /usr/share/cups/ppdc/pcl.h
Conflicts:      cups < 1.6
# Since version 1.14.0 there are no longer sub-packages (except cups-filters-devel).
# The separation of cups-filters into sub-packages was done to make it possible
# to use cups-filters on systems with the traditional CUPS < 1.6
# (i.e. on systems before the SLE12 code base)
# because parts of the cups-filters software conflict with traditional CUPS < 1.6,
# see the comments and package descriptions in older cups-filters.spec.
# But nowadays cups-filters can no longer be built with CUPS < 1.6 with reasonable effort,
# see the entry dated "Wed Oct  7 11:16:13 CEST 2015" in cups-filters.changes.
# On systems with CUPS >= 1.6 (i.e. since SLE12 GA / Leap 42.1) there is no good reason
# to keep cups-filters split into sub-packages and furthermore that split causes
# continuous (nowadays useless) efforts and bugs like
# https://bugzilla.opensuse.org/show_bug.cgi?id=1034877
# Therefore the cups-filters main package must provide
# all what was provided by its former sub-packages
# i.e. all sub-packages names and all explicit "Provides"
# and furthermore it obsoletes all the old sub-packages:
Provides:       cups-filters-ghostscript
Obsoletes:      cups-filters-ghostscript < %{version}
Obsoletes:      cups-filters-ghostscript-debuginfo
Provides:       cups-filters-cups-browsed
Provides:       gstoraster
Obsoletes:      cups-filters-cups-browsed < %{version}
Obsoletes:      cups-filters-cups-browsed-debuginfo
Provides:       cups-browsed
Provides:       cups-filters-foomatic-rip
Obsoletes:      cups-filters-foomatic-rip < %{version}
Obsoletes:      cups-filters-foomatic-rip-debuginfo
Provides:       foomatic-rip
# Provide foomatic-filters with the exact foomatic_rip_version
# see https://bugzilla.novell.com/show_bug.cgi?id=870621
# and conflict with any other foomatic-filters version because
# the following files are also provided by foomatic-filters
# /usr/lib/cups/filter/foomatic-rip /usr/share/man/man1/foomatic-rip
# Regardless that foomatic-filters exists only up to SLE11 and openSUSE 13.1
# it is still built in the OBS "Printing" project for current SLE12 and
# openSUSE Leap and Tumbleweed so that the conflict is still needed.
# The RPM documentation http://www.rpm.org/max-rpm/s1-rpm-depend-manual-dependencies.html
# and /usr/share/doc/packages/rpm/manual/dependencies (in rpm-4.8.0 in openSUSE 11.4)
# does not show a comparison operator for "not equal" so that two Conflicts are used:
Conflicts:      foomatic-filters < %{foomatic_rip_version}
Provides:       foomatic-filters = %{foomatic_rip_version}
Conflicts:      foomatic-filters > %{foomatic_rip_version}
# /usr/bin/pdftops (provided by poppler-tools)
# is needed (but not required for non-PostScript printers)
# to print PDFs on PostScript printers because in this case
# the CUPS filter chain is:
#  /usr/lib/cups/filter/pdftopdf
#  /usr/lib/cups/filter/pdftops
#  where /usr/lib/cups/filter/pdftops calls /usr/bin/pdftops
#  /usr/lib/cups/backend/...
# see https://bugzilla.novell.com/show_bug.cgi?id=868148
Recommends:     poppler-tools

%description
Contains backends, filters, and other software
that was once part of the core CUPS distribution
but is no longer maintained by Apple Inc.
In addition it contains additional filters
and software developed independently of Apple,
especially filters for the PDF-centric printing
workflow introduced by OpenPrinting and a daemon
to browse broadcasts of remote CUPS printers
and makes these printers available locally.
Since Ghostscript version 9.10 the CUPS filters
gstoraster and gstopxl are removed from Ghostscript.
Those filters are now provided by cups-filters.
Since cups-filters version 1.0.42 foomatic-rip
is also provided by cups-filters.
Since CUPS >= 1.6 the CUPS Browsing functionality
is dropped in CUPS. The OpenPrinting cups-browsed
is a daemon running in parallel to the CUPS daemon
to provide again basic CUPS Browsing functionality.
This way basic CUPS Browsing works on clients
with CUPS >= 1.6 when there are remote CUPS servers
of CUPS version 1.5 and older in the network.
Load-balancing (what CUPS <= 1.5 did via implicit classes)
is not supported with cups-browsed.

%package devel
Summary:        Development files for cups-filters
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
# Conflict with cups-devel < 1.6 because up to CUPS 1.5.4
# the following files are provided by the cups-devel package
# /usr/share/cups/ppdc/escp.h
# /usr/share/cups/ppdc/pcl.h
Conflicts:      cups-devel < 1.6

%description devel
This package contains the development files for cups-filters.

%prep
%setup -q
# Since ghostscript 9.27 the internal and undocumented "pdfdict" is gone, switch over to "runpdfbegin"
%patch7
# Backport from V1.22.2 due bug boo#1128167 -- "No destination host name supplied by cups-browsed"
# occurs if "LocalQueueNamingRemoteCUPS RemoteName" is set in cups-browsed.conf
%patch8 

%build
# Just do what is described in the upstream INSTALL file
# unless there is a really good reason not to do it this way
# and then it is probably worth submitting an upstream issue report to
# https://bugs.linuxfoundation.org for "Product: OpenPrinting" and "Component: cups-filters"
./autogen.sh
# No need to set our preferred architecture-specific flags for the compiler and linker
# via export CFLAGS="$RPM_OPT_FLAGS" and export CXXFLAGS="$RPM_OPT_FLAGS"
# because the RPM macro configure does that.
# --with-pdftops=pdftops - use Poppler instead of Ghostscript (see README)
# --enable-braille - enable Braille embosing filters, requires liblouis
# --disable-mutool - disable mupdf processing as we use ghostcript
%configure --disable-static \
           --disable-mutool \
           --disable-silent-rules \
           --enable-shared \
           --enable-imagefilters \
           --enable-braille \
           --enable-ijs \
           --enable-opvp \
           --with-pdftops=pdftops \
           --with-browseremoteprotocols=DNSSD,CUPS \
           --without-php \
	   --with-rcdir=no \
	   --with-test-font-path=/usr/share/fonts/truetype/DejaVuSans.ttf
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%make_install
# As band-aid for now remove the "# BrowseAllow cups.example.com" example line in cups-browsed.conf
# because currently hostnames do not work, see https://bugs.linuxfoundation.org/show_bug.cgi?id=1205
if grep -q '^# BrowseAllow cups.example.com' %{buildroot}%{_sysconfdir}/cups/cups-browsed.conf
then sed -i -e '/^# BrowseAllow cups.example.com/d' %{buildroot}%{_sysconfdir}/cups/cups-browsed.conf
else echo "No longer '# BrowseAllow cups.example.com' in cups-browsed.conf - clean up cups-filters.spec"
     exit 9
fi
# https://fedoraproject.org/wiki/Packaging_tricks#With_.25doc
mkdir __doc
mv %{buildroot}%{_datadir}/doc/cups-filters/* __doc
rm -r %{buildroot}%{_datadir}/doc/cups-filters
mv fontembed/README __doc/fontembed.README
# Install the cups-browsed.service systemd unit file from the upstream sources:
mkdir -p %{buildroot}%{_unitdir}
install -p -m 644 utils/cups-browsed.service %{buildroot}%{_unitdir}
# Provide SUSE policy symlink /usr/sbin/rcFOO -> /etc/init.d/FOO
# /usr/sbin/service exists only since openSUSE 12.3:
%if 0%{?suse_version} > 1220
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rccups-browsed
%else
ln -s /sbin/service %{buildroot}%{_sbindir}/rccups-browsed
%endif
# Don't ship libtool la files.
rm -f %{buildroot}%{_libdir}/lib*.la
# Not sure what is this good for
rm -f %{buildroot}%{_bindir}/ttfread

%pre
# For cups-browsed:
%service_add_pre cups-browsed.service
exit 0

%post
# For cups-browsed:
%service_add_post cups-browsed.service
# Re-configure dynamic linker run-time bindings:
/sbin/ldconfig
exit 0

%preun
# For cups-browsed:
%service_del_preun cups-browsed.service
exit 0

%postun
# For cups-browsed:
%service_del_postun cups-browsed.service
# Re-configure dynamic linker run-time bindings:
/sbin/ldconfig
exit 0

%files
# The files sections list all mandatory files explicitly one by one.
# In particular all executables are listed explicitly.
# This avoids that whatever configure magic might silently
# not build and install an executable when whatever condition
# for configure's automated tests is not fulfilled in the build system,
# (cf. https://bugzilla.novell.com/show_bug.cgi?id=526847#c9).
# When all mandatory files are explicitly listed,
# the build fails intentionally if a mandatory file was not built
# which ensures that already existing correctly built binary RPMs
# are not overwritten by broken RPMs where mandatory files are missing.
%defattr(-,root,root)
%doc __doc/README __doc/AUTHORS __doc/NEWS __doc/COPYING __doc/fontembed.README
%config(noreplace) %{_sysconfdir}/fonts/conf.d/99pdftoopvp.conf
%config(noreplace) %{_sysconfdir}/cups/cups-browsed.conf
%{_unitdir}/cups-browsed.service
%{_sbindir}/cups-browsed
%{_sbindir}/rccups-browsed
%{_mandir}/man5/cups-browsed.conf.5.gz
%{_mandir}/man8/cups-browsed.8.gz
%{_bindir}/driverless
%{_mandir}/man1/driverless.1.gz
%{_bindir}/foomatic-rip
%{_mandir}/man1/foomatic-rip.1.gz
%dir /usr/lib/cups
%dir /usr/lib/cups/driver
/usr/lib/cups/driver/driverless
%dir /usr/lib/cups/backend
%attr(0755,root,root) /usr/lib/cups/backend/beh
%attr(0755,root,root) /usr/lib/cups/backend/implicitclass
%attr(0755,root,root) /usr/lib/cups/backend/parallel
%attr(0755,root,root) /usr/lib/cups/backend/cups-brf
# Serial backend needs to run as root
# see https://bugzilla.redhat.com/show_bug.cgi?id=212577#c4
%attr(0700,root,root) /usr/lib/cups/backend/serial
# Explicit attr() mode not applicable to symlink /usr/lib/cups/backend/driverless
/usr/lib/cups/backend/driverless
%dir /usr/lib/cups/filter
%attr(0755,root,root) /usr/lib/cups/filter/bannertopdf
%attr(0755,root,root) /usr/lib/cups/filter/brftopagedbrf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/cgmtopdf
/usr/lib/cups/filter/cgmtopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/cmxtopdf
/usr/lib/cups/filter/cmxtopdf
%attr(0755,root,root) /usr/lib/cups/filter/commandtoescpx
%attr(0755,root,root) /usr/lib/cups/filter/commandtopclx
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/emftopdf
/usr/lib/cups/filter/emftopdf
%attr(0755,root,root) /usr/lib/cups/filter/foomatic-rip
%attr(0755,root,root) /usr/lib/cups/filter/gstoraster
%attr(0755,root,root) /usr/lib/cups/filter/gstopxl
%attr(0755,root,root) /usr/lib/cups/filter/gstopdf
%attr(0755,root,root) /usr/lib/cups/filter/imagetopdf
%attr(0755,root,root) /usr/lib/cups/filter/imagetops
%attr(0755,root,root) /usr/lib/cups/filter/imagetoraster
%attr(0755,root,root) /usr/lib/cups/filter/musicxmltobrf
%attr(0755,root,root) /usr/lib/cups/filter/pdftoijs
%attr(0755,root,root) /usr/lib/cups/filter/pdftoopvp
%attr(0755,root,root) /usr/lib/cups/filter/pdftopdf
%attr(0755,root,root) /usr/lib/cups/filter/pdftops
%attr(0755,root,root) /usr/lib/cups/filter/pdftoraster
%attr(0755,root,root) /usr/lib/cups/filter/rastertoescpx
%attr(0755,root,root) /usr/lib/cups/filter/rastertopclm
%attr(0755,root,root) /usr/lib/cups/filter/rastertopclx
%attr(0755,root,root) /usr/lib/cups/filter/rastertops
%attr(0755,root,root) /usr/lib/cups/filter/rastertopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/svgtopdf
/usr/lib/cups/filter/svgtopdf
%attr(0755,root,root) /usr/lib/cups/filter/sys5ippprinter
%attr(0755,root,root) /usr/lib/cups/filter/vectortobrf
%attr(0755,root,root) /usr/lib/cups/filter/vectortopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/vectortoubrl
/usr/lib/cups/filter/vectortoubrl
%attr(0755,root,root) /usr/lib/cups/filter/texttopdf
%attr(0755,root,root) /usr/lib/cups/filter/texttops
%attr(0755,root,root) /usr/lib/cups/filter/texttotext
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/wmftopdf
/usr/lib/cups/filter/wmftopdf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/xfigtopdf
/usr/lib/cups/filter/xfigtopdf
# See the "./configure --help" output
#  --with-apple-raster-filter=rastertopdf|urftopdf
#    Select filter for Apple Raster input. Default:
#    rastertopdf for CUPS 2.2.2+, urftopdf for older CUPS
# and see in the NEWS file the CHANGES IN V1.13.0
#  - rastertopdf, urftopdf: As with libcupsimage from CUPS 2.2.2
#    on rastertopdf also understands Apple Raster and much better
#    than urftopdf does, use rastertopdf for Apple Raster
#    (image/urf) input files then. Also allow for manually
#    choosing by the ./configure command line.
# Because Factory/Tumbleweed uses CUPS in the Printing project for build
# (which is currently CUPS 2.2.3 as of this writing Fri Jun 2)
# the filter for Apple Raster input is rastertopdf
# so that /usr/lib/cups/filter/urftopdf must be excluded
# from the RPM files list for Factory/Tumbleweed.
# For the current suse_version value for openSUSE Factory see
# https://en.opensuse.org/openSUSE:Build_Service_cross_distribution_howto
# because that value changes:
%if 0%{?suse_version} <= 1320
%attr(0755,root,root) /usr/lib/cups/filter/urftopdf
%endif
# Filters for braille embosser support:
%attr(0755,root,root) /usr/lib/cups/filter/brftoembosser
%attr(0755,root,root) /usr/lib/cups/filter/imagetobrf
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/imagetoubrl
/usr/lib/cups/filter/imagetoubrl
%attr(0755,root,root) /usr/lib/cups/filter/imageubrltoindexv3
%attr(0755,root,root) /usr/lib/cups/filter/imageubrltoindexv4
%attr(0755,root,root) /usr/lib/cups/filter/textbrftoindexv3
# Explicit attr() mode not applicable to symlink /usr/lib/cups/filter/textbrftoindexv4
/usr/lib/cups/filter/textbrftoindexv4
%attr(0755,root,root) /usr/lib/cups/filter/texttobrf
%dir %{_datadir}/cups
%{_datadir}/cups/banners
# Shell helpers for braille embosser support:
%{_datadir}/cups/braille
%{_datadir}/cups/charsets
%dir %{_datadir}/cups/data
%{_datadir}/cups/data/*
%dir %{_datadir}/cups/drv
%{_datadir}/cups/drv/cupsfilters.drv
# Driver info files for braille embosser support:
%{_datadir}/cups/drv/generic-brf.drv
%{_datadir}/cups/drv/generic-ubrl.drv
%{_datadir}/cups/drv/indexv3.drv
%{_datadir}/cups/drv/indexv4.drv
%dir %{_datadir}/cups/mime
%{_datadir}/cups/mime/cupsfilters.types
%{_datadir}/cups/mime/cupsfilters.convs
%{_datadir}/cups/mime/cupsfilters-ghostscript.convs
%{_datadir}/cups/mime/cupsfilters-poppler.convs
# MIME conversion types and rules for braille embosser support:
%{_datadir}/cups/mime/braille.types
%{_datadir}/cups/mime/braille.convs
# CUPS PPD file compiler driver information files for braille embosser support:
%dir %{_datadir}/cups/ppdc
%{_datadir}/cups/ppdc/braille.defs
%{_datadir}/cups/ppdc/fr-braille.po
%{_datadir}/cups/ppdc/imagemagick.defs
%{_datadir}/cups/ppdc/index.defs
%{_datadir}/cups/ppdc/liblouis.defs
%{_datadir}/cups/ppdc/liblouis1.defs
%{_datadir}/cups/ppdc/liblouis2.defs
%{_datadir}/cups/ppdc/liblouis3.defs
%{_datadir}/cups/ppdc/liblouis4.defs
%{_datadir}/cups/ppdc/media-braille.defs
# PPD files:
%dir %{_datadir}/ppd
%{_datadir}/ppd/cupsfilters
# Libraries:
%{_libdir}/libcupsfilters.so.*
%{_libdir}/libfontembed.so.*

%files devel
%defattr(-,root,root)
%dir %{_datadir}/cups/ppdc
%{_datadir}/cups/ppdc/pcl.h
%{_datadir}/cups/ppdc/escp.h
%{_libdir}/libcupsfilters.so
%{_libdir}/libfontembed.so
%{_libdir}/pkgconfig/libcupsfilters.pc
%{_libdir}/pkgconfig/libfontembed.pc
%{_includedir}/cupsfilters
%{_includedir}/fontembed

%changelog
* Tue Oct 15 2019 Dr. Werner Fink <werner@suse.de>
- Add patch cups-filters-f0e1fc43.patch which is a backport from
  V1.22.2 due bug boo#1128167 -- "No destination host name supplied by cups-browsed"
  occurs if "LocalQueueNamingRemoteCUPS RemoteName" is set in cups-browsed.conf
* Fri Oct  4 2019 Dr. Werner Fink <werner@suse.de>
- Add patch cups-filters-297cc2de-gs-9.27.patch
  * foomatic-rip: Changed Ghostscript call to count pages in a
    PDF file to use "runpdfbegin" and not the undocumented
    Ghostscript internal "pdfdict", so that it works with
    Ghostscript 9.27 and later (boo#1152720)
* Wed May  2 2018 luizluca@gmail.com
- Version upgrade to 1.20.3
  to fix regression from 1.20.2 that ignores printers published
  using legacy CUPS broadcast
* Tue Apr 10 2018 jsmeix@suse.de
- Version upgrade to 1.20.2
  to provide upstream bugfixes also for SLE15 / Leap15
  and be also already prepared for SLE12 (fate#323676).
  This is a bug fix release fixing the recognition
  of remote CUPS queues by cups-browsed, the behavior
  of cups-browsed when one creates a queue with the
  same name of a cups-browsed-generated queue overwriting
  it, and other bug fixes (for details see the NEWS file).
* Wed Apr  4 2018 jsmeix@suse.de
- Version upgrade to 1.20.1
  to provide upstream bugfixes also for SLE15 / Leap15
  and be also already prepared for SLE12 (fate#323676).
  This is a bug fix release fixing several issues
  on the Braille support and other bugs, in particular
  (for details see the NEWS file):
  * libcupsfilters: Silenced warning when using CUPS < 2.x
    by eliminating the use of a recently introduced
    CUPS library function, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1421
  * cups-browsed: Fixed crash when CUPS reports a print queue
    without "device-uri" attribute when cups-browsed polls a
    list of local CUPS queues, see
    https://github.com/OpenPrinting/cups-filters/issues/16
- fix_upstream_bug_1421.patch is no longer needed because
  it is now fixed in the upstream sources
  (see the "libcupsfilters ... bug ... 1421" entry above).
* Wed Feb 21 2018 jsmeix@suse.de
- Version upgrade to 1.20.0:
  * Mainly enhancements and fixes for the PPD generator.
  * For detailed info see the NEWS file.
- fix_upstream_bug_1421.patch is the upstream fix for
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1421
- Use 'BuildRequires python3-cups' only if suse_version >= 1330
  (cf. "Do not require python-cups but rather python3-cups" below)
  which means after any SLE12 service pack and after any Leap 42.x
  i.e. for Tumbleweed, Leap 15.x, and the upcoming SLE15 and later
  otherwise still use 'BuildRequires python-cups' to make it build
  and usable again not only on some newest systems according to
  https://en.opensuse.org/openSUSE:How_to_contribute_to_the_Printing_project
* Tue Jan 23 2018 tchvatal@suse.com
- Version upgrade to 1.19.0:
  * See the detailed stuff in NEWS file
  * New filters and poppler compatibility as always
- Do not require python-cups but rather python3-cups in order to
  allow build on python2 less system
- Explicitly enable ijs and opvp filters
* Fri Sep 29 2017 olaf@aepfle.de
- Obsolete also debuginfo subpackages of the packages marked as
  Obsoletes in this specfile (bsc#1047897)
* Sat Sep 16 2017 zaitor@opensuse.org
- Version upgrade to 1.17.6:
  * As the changelog is long for detailed info check the NEWS file.
  * Package new filters.
  * Compatible with poppler 0.58 and newer (Bug #1408).
* Fri Jun  2 2017 jsmeix@suse.de
- The filter for Apple Raster input is rastertopdf
  for CUPS 2.2.2+ and urftopdf for older CUPS.
  Because Factory/Tumbleweed uses the newest CUPS for build
  (which is currently CUPS 2.2.3 as of this writing) the filter
  for Apple Raster input is rastertopdf for Factory/Tumbleweed
  so that /usr/lib/cups/filter/urftopdf must be excluded
  from the RPM files list for Factory/Tumbleweed.
* Thu Jun  1 2017 jsmeix@suse.de
- The RPM scriptlet hack that created a special cupsfilters.convs
  so that the gstoraster filter can be used with CUPS <= 1.5.4
  does no longer make sense and is therefore removed.
* Tue May 30 2017 jsmeix@suse.de
- Since version 1.14.0 there are no longer sub-packages
  (except cups-filters-devel) because nowadays cups-filters
  can no longer be built with CUPS < 1.6 with reasonable effort,
  see the entry below dated "Wed Oct  7 11:16:13 CEST 2015".
  On systems with CUPS >= 1.6 (i.e. since SLE12 GA / Leap 42.1)
  there is no good reason to keep cups-filters split into
  sub-packages and furthermore that split causes continuous
  (nowadays useless) efforts and bugs (like boo#1034877).
- Version upgrade to 1.14.0:
  Some excerpts (for details see the NEWS file):
  * cups-browsed: Added new setting "LocalOnly" for the
    CreateIPPPrinterQueues in cups-browsed.conf.
- Version upgrade to 1.13.5:
  Some excerpts (for details see the NEWS file):
  * foomatic-rip: When called via cupsfilter, foomatic-rip was
    not able to read the PPD file with (Bug #1388).
  * cups-browsed: When creating a local queue for a remote CUPS
    printer, add the line '*APRemoteQueueID: ""' to the PPD file
    so that CUPS sets the CUPS_PRINTER_REMOTE bit for the
    printer type of the local queue (Bug #1386).
- fallback_read_ppd_file_from_environment.patch is no longer
  needed because it is now provided in the upstream sources
  (see the "Bug #1388" entry above).
- Version upgrade to 1.13.4:
  Some excerpts (for details see the NEWS file):
  * cups-browsed: Corrected determination whether an IPP status
    is an error, to avoid "Unable to create/modify CUPS queue
    (Success)" and infinite repetition of a succeeded operation
    (Debian bug #852436).
* Mon Mar 13 2017 jsmeix@suse.de
- fallback_read_ppd_file_from_environment.patch
  lets foomatic-rip call read_ppd_file() with
  PPD filename from environment as fallback, see
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1388
* Fri Jan 20 2017 tchvatal@suse.com
- Version upgrade to 1.13.3:
  * As the changelog is long for detailed info check the NEWS file
  * Disable mutool switch to not build with mupdf package in order
    to not expand the dependencies too much
  * /usr/lib/cups/filter/textonly was renamed to texttotext
  * pstopdf filter dropped by upstream (cf. boo#1036220)
  * Add new driverless binary/driver to work with
    new style IPP printers that do not require any driver
* Thu Mar  3 2016 jsmeix@suse.de
- Version upgrade to 1.8.2
  * Allow disabling dependencies on Ghostscript and Foomatic
    (Bug #1342).
  * cups-browsed: Optionally generate also local queues pointing
    to remote raw queues. Usually only queues pointing to remote
    queues with PPD/driver are created (Debian bug #814020,
    Debian bug #756724).
- Version upgrade to 1.8.1
  * cups-browsed: Do not disable queues which still have jobs (and
    therefore cannot be removed) when avahi-daemon goes away, the
    print server is most probably still available and printing can
    be continued. Especially important on mobile devices where
    avahi-daemon is shut down when the print dialog is closed (and
  the job(s) still printing).
- Version upgrade to 1.8.0
  * COPYING: Replaced the COPYING file by a file in Debian format,
    derived from Debian's file but updated and corrected.
  * braille: Added info about additional packages needed for
    Braille printing to the README file.
  * braille: Let the Braille filters use lou_translate of
    liblouis if the more sophisticated file2brl of liblouisutdml
    is not installed. This is decided on at run time, so later
    installation of liblouisutdml will let the filters
    automatically switch to file2brl.
  * braille: Allow to build with Braille support also if
    liblouis is not installed at build time.
  * braille: Added checks for the presence of helper tools, to
    get clear messages in the CUPS error_log if something is
    missing.
  * Fixed copyright headers of files inherited from CUPS or
    derived from CUPS, pointing to COPYING as license info file,
    removing Apple exceptions, removing hints that a missing
    license info file can be found at www.cups.org, and removing
    "$Id" SVN file ID placeholders.
  * Updated COPYING file for missing implicitclass and beh
    backends.
- Version upgrade to 1.7.0
  * cups-browsed: Added possibility to trigger the auto shutdown
    by the queues of cups-browsed being without jobs. Before
    auto shutdown was only possible when all queues have gone
    away. This allows auto shutdown on mobile devices where
    avahi-daemon is also used for other things than printing.
- Version upgrade to 1.6.0
  * cups-browsed: Fixed use of CUPS domain socket, both
    detection during build process and permission check at
    runtime.
  * foomatic-rip: Fixed buffer overflow when reading environment
    variables CUPS_FONTPATH, CUPS_DATADIR, and GS_LIB (Bug
    [#1336]).
  * beh: Introduced beh, the Backend Error Handler, a wrapper
    backend to make handling of backend errors more
    configurable. This backend is a C re-write of the beh
    backend written in Perl which was part of the former
    foomatic-filters package. Several people asked for beh
    getting moved to cups-filters.
  * braille: Make image printing working also if ImageMagick
    generates formatted images without header.
  * braille: If the user does not select a Braille translation,
    let the embosser do the translation.
  * cups-browsed: Added version info to help screen and start-up
    in debug mode, call help screen also via "--version" option.
  * cups-browsed: Minor improvements in help screen and man page.
- Version upgrade to 1.5.0
  * cups-browsed: Allow use of an alternative configuration file
    via the "-c" command line option.
  * cups-browsed: Allow supplying configuration settings via the
    command line using the "-o" command line option.
  * cups-browsed: Command line help via the "-h" or "--help"
    command line option.
* Thu Dec 17 2015 jsmeix@suse.de
- Version upgrade to 1.4.0
  Changes in 1.4.0 (excerpt - for details see the NEWS file):
  * foomatic-rip: SECURITY FIX: Also consider the semicolon
    (';') as an illegal shell escape character. Thanks to Adam
    Chester (adam dot chester at pentest dot co dot uk) for the
    hint CVE-2015-8560 (bsc#957531).
  * brftoembosser, imagetobrf, imagetoubrl, imageubrltoindexv3,
    imageubrltoindexv4, textbrftoindexv3, textbrftoindexv4,
    texttobrf, braille.convs, braille.types, generic-brf.drv,
    indexv3.drv, indexv4.drv: Added support for Braille
    embossing via CUPS. Text and even images can now be sent to
    a Braille embosser like to a printer. Thanks to Samuel
    Thibault (samuel dot thibault at ens-lyon dot org) for this
    contribution.
- BuildRequires liblouis-devel is needed for Braille embossers.
- Version upgrade to 1.3.0
  Changes in 1.3.0 (excerpt - for details see the NEWS file):
  * cups-browsed: Added new BrowseFilter directive in
    cups-browsed.conf.  This directive allows filtering of the
    remote printers to be accepted on most properties/metadata
    supplied with the DNS-SD broadcasts. This allows, in
    addition to BrowseAllow/BrowseDeny/BrowseOrder, to reduce
    the amount of printers listed in print dialogs to a more
    useful amount.
  * cups-browsed: Added support for BrowseDeny and BrowseOrder
    directives in cups-browsed.conf.
  * cups-browsed: Let the BrowseAllow lines in cups-browsed.conf
    also apply to remote printers discovered via DNS-SD.
- Version upgrade to 1.2.0
  Changes in 1.2.0 (excerpt - for details see the NEWS file):
  * foomatic-rip: SECURITY FIX: Also consider the back tick
    ('`') as an illegal shell escape character. Thanks to Michal
    Kowalczyk from the Google Security Team for the hint
    CVE-2015-8327 (bsc#957531).
- Version upgrade to 1.1.0
  Changes in 1.1.0 (excerpt - for details see the NEWS file):
  * Version numbering scheme changed: Releases with feature
    addition/change have the minor number increased now, pure
    bug fix releases get the revision number increased, to make
    use of the minor number which stayed zero all the time.
  * cups-browsed: Added "DefaultOptions" directive to
    cups-browsed.conf to allow defining default option settings
    for local queues to be generated for newly appearing remote
    printers.
  * cups-browsed: Let option settings of a generated print queue
    be saved before taking the queue down so that when the remote
    printer appears again all user changes get restored, making
    user changes permanent on generated queues.
  * cups-browsed: Added a mode in which IP-based device URIs
    for the generation of local print queues are used, for
    cases with problems in local host name resolution.
  * foomatic-rip: Use -dFirstPage=... and -dLastPage=... only
    if really needed (Bug #1324).
  * cups-browsed, implicitclass: Make the load-balancing
    configurable so that one can select whether the jobs get
    queued up locally like in a CUPS class or whether they get
    immediately distributed to the remote servers letting them
    queue up there.
- FirstPage_LastPage_only_if_needed.patch is obsolete since
  version 1.1.0 because it is fixed in the sources.
* Wed Oct  7 2015 jsmeix@suse.de
- FirstPage_LastPage_only_if_needed.patch lets foomatic-rip
  add -dFirstPage=N [and -dLastPage=M] to the Ghostscript
  command line only if those options are actually needed
  (i.e. if FirstPage > 1 [and when LastPage >= FirstPage])
  cf. http://bugs.ghostscript.com/show_bug.cgi?id=696246
  and https://bugs.linuxfoundation.org/show_bug.cgi?id=1324
- At least for now support for cups154 in the SLE12 legacy module
  is abandoned (by default SLE12 has CUPS 1.7.5) because newer
  cups-filters versions again use stuff that is provided
  since CUPS > 1.5.4 so that it does no longer build with
  CUPS 1.5.4. Perhaps I (jsmeix@suse.de) find time to fix it
  again for CUPS 1.5.4 but when not, newer cups-filters will
  no longer work with CUPS 1.5.4.
- Version upgrade to 1.0.76
  Changes in 1.0.76 (excerpt - for details see the NEWS file):
  * cups-browsed, implicitclass: Let the load-balancing queue up
    the jobs in the local (generated) queue until a free (idle,
    enabled, and accepting jobs) remote queue is found (check
    every 5 sec if no free queue available). This gives a more
    even distribution of the work amongst the servers and
    protects against the case that a bunch of jobs gets
    inaccessible or lost if one of the servers fails.
  * cups-browsed: Let the load-balancing also check whether the
    destination queue is actually accepting jobs.
  * cups-browsed: If a generated queue is not removed on
    shutdown of cups-browsed due to remaining jobs in it,
    re-enable it in the next cups-browsed session even if it was
    disabled by something other than cups-browsed.
  * implicitclass: Clean up debug and error messages.
  * implicitclass: Fix exit codes for immediate retry of jobs.
  * cups-browsed: Make absence of CUPS notifications via D-Bus
    non-fatal and fall back to the old behavior of cups-browsed
    (fail-over instead of load balancing for equally-named
    remote queues, do not remove generated queue if it is
    default instead of default printer management). This solves
    problems of CUPS and/or cups-browsed built without D-Bus
    support or absence of D-Bus on the system (Bug #1316).
  * cups-browsed: Do not use g_warning() function, sneaked in
    by copy and paste of CUPS subscription functions.
- Version upgrade to 1.0.75
  Changes in 1.0.75 (excerpt - for details see the NEWS file):
  * texttopdf: Really support BoldItalic (original texttops
    just maps BoldItalic to Bold).
  * texttopdf: Fixed segfault when outputting BoldItalic
    (Bug #1314).
- Version upgrade to 1.0.74
  Changes in 1.0.74 (excerpt - for details see the NEWS file):
  * cups-browsed: Added NULL check when getting the notification
    of a printer starting to process a job and checking whether
    this printer is created by cups-browsed with the
    implicitclass: backend (Ubuntu bug #1488524).
  * cups-browsed: Do not schedule printers for update when they
    are already marked as disappeared.
  * cups-browsed: Added sanity checks when saving the default
    printer selection in a file.
  * cups-browsed, implicitclass: If remote queues disappear or
    cups-browsed shuts down and a cups-browsed-generated queue
    still has jobs and needs to be kept therefore, disable it
    and re-enable it when cups-browsed starts again and/or the
    remote queue(s) re-appear(s). This avoids repeated retries
    of the jobs while the remote server is not available, causing
    unneeded system load and battery consumption.
  * cups-browsed: After polling info from remote CUPS servers
    to find the best destination job, set the default CUPS server
    back to local.
- Version upgrade to 1.0.73
  Changes in 1.0.73 (excerpt - for details see the NEWS file):
  * cups-browsed: Added missing
    utils/org.cups.cupsd.Notifier.xml file.
- Version upgrade to 1.0.72
  Changes in 1.0.72 (excerpt - for details see the NEWS file):
  * cups-browsed, implicitclass: Added load balancing
    functionality. If there are several remote CUPS printers
    with the same name, they for locally a cluster represented
    by a print queue with this name. This printer prints through
    a special backend (implicitclass) which makes cups-browsed
    find the best destination remote queue (fewest jobs,
    enabled) for this job.
  * cups-browsed: Added protection against accidental deletion of
    print queues generated by cups-browsed. These queues now get
    automatically re-created.
  * cups-browsed: Added LDAP support. Appropriately configured
    via cups-browsed.conf remote printers made available via LDAP
    will be looked up and local queues pointing to them created.
    Thanks to Raphael Geissert (atomo64 at gmail dot com) for
    contributing this patch (Debian bug #795185).
  * cups-browsed: Introduced new handling for the default printer
    using cache files. So we do not need to keep an auto-generated
    queue because it is set as default printer. If the
    auto-generated queue disappears, the old local printer is set
    as default again and when it re-appears it returns to be the
    default printer.
  * cups-browsed: Added infrastructure for subscribing to CUPS
    notifications for things like improved default printer
    handling, load balancing, ...
  * foomatic-rip: Prevent crash when supplying "media" option with
    empty value ("media=", Ubuntu bug #1479871).
  * pdftoopvp: Adaptations to API changes on Poppler 0.34.0, note
    that this patch disables color management in this filter.
    Thanks to Vincent le Garrec and Andreas K. Huettel for the
    patch (Bug #1301, Gentoo bug #554782).
  * texttopdf: Request the generic 'monospace' font alias from
    fontconfig instead of the hard-coded FreeMono. Thanks
    to Fabian Greffrath (fabian at debian dot org) for the
    patch (Debian bug #788048).
- cups-filters-poppler-034.patch is obsolete since version 1.0.72
  because it is fixed in the sources.
* Thu Sep  3 2015 jsmeix@suse.de
- More appropriate URL entry in spec file:
  Now it is (wrapped URL)
  http://www.linuxfoundation.org/collaborate/workgroups
    /openprinting/cups-filters
  that shows mainly generic information instead of (wrapped URL)
  http://www.linuxfoundation.org/collaborate/workgroups
    /openprinting/pdf_as_standard_print_job_format
  that provides mainly technical details.
* Sun Jul 26 2015 zaitor@opensuse.org
- Add cups-filters-poppler-034.patch: Fix build with poppler-0.34.
  See https://bugs.linuxfoundation.org/show_bug.cgi?id=1301
  pdftoopvp: Adaptations to API changes on Poppler 0.34.0, note
  that this patch disables color management in this filter.
* Mon Jul  6 2015 jsmeix@suse.de
- Version upgrade to 1.0.71
  Changes in 1.0.71 (cf. the NEWS file but there is a typo
  in the NEWS file that claims the CVE number is 3259
  while the correct CVE number is 3279):
  * texttopdf: The Page allocation is moved into textcommon.c,
    where it does all the necessary checking:
    lower-bounds for CVE-2015-3258 (bsc#936281) and
    upper-bounds for CVE-2015-3279 (bsc#937018)
    due to integer overflows for the calloc() call
    initialising Page[0] and the memset() call in texttopdf.c's
    WritePage() function zeroing the entire array.
    Thanks to Tim Waugh from Red Hat for the patch.
  * texttopdf: Upper-bounds checking CVE-2015-3279 (bsc#937018).
* Mon Jun 29 2015 jsmeix@suse.de
- Version upgrade to 1.0.70
  Changes in 1.0.70 (excerpt - for details see the NEWS file):
  * texttopdf: Fixed buffer overflow on size allocation
    of texttopdf when working with extremely small line sizes,
    which causes the size calculation to result in 0
    CVE-2015-3258 (bsc#936281), thanks to Stefan Cornelius
    from Red Hat for the patch.
  * cups-browsed: leak fixes
  * cups-browsed: Further BrowseAllow fixing
  * cups-browsed: BrowsePoll is an array of pointers,
    not structures, so allocate room for the pointers
  * cups-browsed: Prevent NULL dereference when handling
    BrowseAllow without value
  * cups-browsed: Use memory deallocation function
    corresponding to allocation function used
  * cups-browsed: Fixes for glib source handling
    (Red Hat bug #1228555)
- Version upgrade to 1.0.69
  Changes in 1.0.69 (excerpt - for details see the NEWS file):
  * cups-browsed: When checking whether a queue name already
    exists as a locally defined queue, do case-insensitive
    comparing as for CUPS printer names are case-insensitive.
    This assures that already existing queues do never get
    overwritten.
  * cups-browsed: Added "IPPPrinterQueueType Auto/PPD/NoPPD"
    directive to cups-browsed.conf to allow controlling how
    cups-browsed creates queues fr native IPP network printers:
    with PPD, with System V interface script, or selecting
    automatically.
  * pdftopdf: Center Landscape-oriented jobs correctly
    on the page if the "fitplot" or "number-up" options
    are used (Bug #1284).
  * pstopdf: Removed "-dUseCIEColor" from the Ghostscript command
    line. In modern Ghostscript versions (9.11 and newer) it is
    recommended to not use it with the pdfwrite and ps2write
    output devices any more.
  * imagetopdf: Corrections in PDF output: Let evince display
    the PDF with the correct size including margins and let
    ghostscript not complain about an invalid xref entry.
  * sys5ippprinter: Renamed pdftoippprinter to reflect that it is
    once a System 5 interface script and second does not accept
    only PDF as input.
  * pdftoippprinter: Support also PWG Raster and JPEG as input
    formats so that an auto-generated, PPD-less queue for an
    IPP printer emulates an IPP Everywhere printer.
* Thu May 14 2015 tchvatal@suse.com
- Version bump to 1.0.68:
  * cups-browsed: Numeric IDs for GSources of the glib event
    loop must be positive integers greater than zero according
    to the documentation of the g_source_get_id() function.
    Taken care of this at all places.
  * cups-browsed: Added conditionals so that it also builds with
    CUPS 1.5.x (but then withou support for automatically creating
    queues for IPP network printers). Thanks to Johannes Meixner
    from SUSE for the patch (Bug #1268).
  * Ricoh-PDF_Printer-PDF.ppd: Added PPD file for Ricoh's PDF
    printers (experimental). Thanks to Ulrich Wehner from Ricoh
    for the file.
- Remove upstream merged patch:
  * fix-create_local_queue-ifndef-HAVE_CUPS_1_6.diff
* Fri Mar 20 2015 jsmeix@suse.de
- For SLE12 build it with traditional CUPS 1.5.4 to ensure
  it works on SLE12 both with CUPS 1.7.5 and CUPS 1.5.4.
* Fri Mar 20 2015 jsmeix@suse.de
- fix-create_local_queue-ifndef-HAVE_CUPS_1_6.diff
  makes it compile again without errors also for CUPS <= 1.5.4
  by excluding code that uses CUPS >= 1.6 specific stuff,
  in particular by skipping create_local_queue for non-CUPS
  printer broadcasts for CUPS <= 1.5.4, see the upstream bug
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1268
* Thu Mar 12 2015 tchvatal@suse.com
- Reenable threads, seems to work fine. If there are thread
  related issues assign the bug to me.
* Thu Mar 12 2015 jsmeix@suse.de
- Version upgrade to 1.0.67
  Changes in 1.0.67:
  * cups-browsed: Use g_source_remove() instead of
    g_source_destroy() for killing auto shutdown timers
    (Ubuntu bug #1427344).
* Sat Mar  7 2015 tchvatal@suse.com
- Do no longer create foomatic-rip symlink that is now done
  by make install command (see linuxfoundation.org bug #1255
  and the entry dated "Mon Aug 25 15:30:37 CEST 2014" below).
- Fix postun call on cups-browsed to call right rpm macro
* Sat Mar  7 2015 tchvatal@suse.com
- Version bump to 1.0.66:
  * Many fixes in cups-browsed in particular a SECURITY FIX:
    Fixed a bug in the remove_bad_chars() failing to reliably
    filter out illegal characters if there are two or more
    subsequent illegal characters, allowing execution of arbitrary
    commands with the rights of the "lp" user, using forged print
    service announcements on DNS-SD servers
    (CVE-2015-2265, boo#921753, linuxfoundation.org bug #1265).
  * Compat code for new poppler.
  * For detailed listing see NEWS file in documentation.
- Use .xz for tarball, bit smaller, adds dep on xz, no biggie
- Changes in verion 1.0.63 (excerpts):
  * foomatic-rip: Added hint to man page that direct,
    spooler-less mode is mainly for testing and debugging
    (linuxfoundation.org bug #1253, bsc#915545)
  * foomatic-rip: Added a symlink of the filter to the
    binary executable directory (usually /usr/bin),
    so that LSB compliance test scripts work
    (linuxfoundation.org bug #1255, bsc#915545).
* Mon Nov 10 2014 jsmeix@suse.de
- During installation of a whole openSUSE system
  cups-filters-ghostscript can be installed before cups
  and then there is no /usr/share/cups/mime/ directory
  so that it is created if needed (bnc#904652).
* Mon Aug 25 2014 jsmeix@suse.de
- A /usr/bin/foomatic-rip -> /usr/lib/cups/filter/foomatic-rip
  symlink is added to the cups-filters-foomatic-rip sub-package
  to make our lsb RPM installable again (bnc#892604).
  LSB currently requires /usr/bin/foomatic-rip but future LSB
  will require /usr/lib/cups/filter/foomatic-rip see
  https://lsbbugs.linuxfoundation.org/show_bug.cgi?id=3900
* Mon Aug 25 2014 jsmeix@suse.de
- Version upgrade to 1.0.58
  Changes in 1.0.58 (excerpt - for details see the NEWS file):
  * pdftoraster: Changed ICC profile get function to accept a
    PPD fallback profile.
  * pdftoraster: Fixed handling of cupsColorSpaces 18,19,20.
  * rastertopdf: Grayscale color conversion now properly inverts
    bits.
  * rastertopdf: Implemented basic 8bit->8bit color space
    conversions.
  * rastertopdf: Added black point compensation.
  * rastertopdf: Added handling of color rendering intent.
  * gstoraster, imagetoraster, pdftoraster, rastertopclx,
    rastertopdf, foomatic-rip: Use color management functions in
    libcupsfilters.
  * libcupsfilters: Modified code formatting and documentation in
    the color management functions.
  * libcupsfilters: Fixed string handling and added debug log
    messages in the color management functions.
  * libcupsfilters: Fixed Adobe RGB matrix for proper rendering
    (transpose)
  * libcupsfilters: Moved color management functions from the
    individual filters to the libcupsfilters library.
- Version upgrade to 1.0.57
  Changes in 1.0.57 (excerpt - for details see the NEWS file):
  * Build system: Explicitly link to libm as -lm was dropped
    from cups-config --libs.
  * libcupsfilters, foomaticrip, gstoraster, imagetoraster,
    pdftoraster, rastertopclx, rastertopdf: Handle absence of
    colord or D-Bus gracefully (Ubuntu bug #1356405).
- Version upgrade to 1.0.56
  Changes in 1.0.56 (excerpt - for details see the NEWS file):
  * Major regression fix in cups-browsed (introduced in 1.0.55
    by no longer creating a local queue pointing to a remote
    raw queue that causes no longer creating local queues for
    traditional CUPS Browsing remote CUPS queues):
    Do not consider a remote CUPS queue as raw if the TXT record
    is NULL as for queues broadcasted by the legacy CUPS method
    the TXT record does not exist. Now  consider a queue with
    NULL TXT record only as raw if the domain entry is not empty
    which tells that the queue is Bonjour-broadcasted
    (linuxfoundation.org bug #1223).
  * cups-browsed: Do also not mark a discovered printer as
    already provided by another server when the other server's
    queue has "unconfirmed" status. Mark the other queue with
    "disappeared" or "unconfirmed" status as duplicate of the
    discovered printer so that the new queue for the discovered
    printer does not get removed when the entry for the other
    queue times out.
  * rastertopdf: Some code polishing and removal of now unneeded
    functions
  * rastertopdf: Reduced color space handling to only
    PWG-supported color spaces
  * rastertopdf: Added colorspace calibration function; included
    optional "/Alternate" PDF key for ICC profile embedding
  * rastertopdf: Colorspace sRGB now embeds srgb icc profile;
    implemented ICC Profile embedding (PDF 1.3 spec)
  * rastertopdf: Added basic color calibration
  * rastertopdf: Implemented ICC Profile creation code for IPP
    Everywhere (from PWG raster)
  * pdftoraster: Added colord handling of ICC profiles
* Wed Jul 30 2014 jsmeix@suse.de
- Version upgrade to 1.0.55
  Changes in 1.0.55 (excerpt - for details see the NEWS file):
  * pdftopdf: Fixed manual duplex by adding a blank page to even
    pages if the total number of pages of the document is odd.
    Otherwise the last page of the document would stay in
    the input tray. This fixes also a side effect as the set of
    even pages reducing to a zero page job if the job consists
    of only one page, making Poppler's pdftops error out
    (Ubuntu bug #1340435).
  * cups-browsed: Do not mark a discovered printer as already
    provided by another server when the other server's queue has
    "disappeared" status. This queue can be from the same server
    before it changed its name.
  * cups-browsed: Do not create a local queue pointing to a
    remote raw queue (Ubuntu bug #1335211).
  * foomatic-rip, imagetoraster, pdftoraster, rastertopclx,
    rastertopdf: Added colord "device_inhibit" support for
    color-managed filters.
  * bannertopdf: Fixed "Printer Location" and "Driver Version"
    entries on test page/banners (linuxfoundation.org bug #1209).
  * bannertopdf: Added new PDF template files which contain the
    text strings appropriate to the banners, before the banners
    were all equal, without text (linuxfoundation.org bug #1209).
  * pstopdf: Use "grep -E" instead of "grep -P" as the latter
    generates executable code and executes it, requiring
    "execmem" privileges which could be not available in some
    security policies. Thanks to Tim Waugh from Red Hat for the
    patch (Red Hat bug #1079534).
  * pdftoraster: Fixed segfault caused by introduction of
    "no-color-management" option (linuxfoundation.org bug #1214).
  * libcupsfilters: Let cupsRasterParseIPPOptions() also accept
    "pwg-raster-document-type" settings with hyphen between
    color space name and color depth.
- Our separated source files classified.pdf confidential.pdf
  secret.pdf standard.pdf topsecret.pdf unclassified.pdf (see
  the entry below dated "Thu Jun 12 17:27:56 CEST 2014") are
  no longer needed because it is now provided in the upstream
  sources (see "linuxfoundation.org bug #1209" entries above).
- Added CVE-2014-4336 CVE-2014-4337 bnc#883543 and
  CVE-2014-4338 bnc#883536 to the matching entry below
  dated "Mon Apr 28 10:49:21 CEST 2014" because those CVEs
  and bncs have not been known at that time (cf. bnc#871327
  therein comment#47 and bnc#883307 therein comment#2).
* Thu Jun 12 2014 jsmeix@suse.de
- Have different header texts for the PDF-BANNER printouts
  (same headers as on the CUPS <= 1.5.4 banner pages):
  Provide PDF template files classified.pdf confidential.pdf
  secret.pdf standard.pdf topsecret.pdf unclassified.pdf and
  modify the matching /usr/share/cups/banners/ template files
  accordingly to use those PDF templates
  (see https://bugs.linuxfoundation.org/show_bug.cgi?id=1209).
* Wed Jun 11 2014 jsmeix@suse.de
- Version upgrade to 1.0.54
  Changes in 1.0.54 (excerpt):
  * pdftoraster: Support for output in the color spaces 18
    (CUPS_CSPACE_SW, sGray), 19 (CUPS_CSPACE_SRGB, sRGB), and 20
    (CUPS_CSPACE_ADOBERGB, Adobe RGB). No color management
    appropriate to these color spaces is added yet.
  * rastertopdf: Added new filter to convert PWG Raster input
    into a PDF file (using QPDF). This filter makes CUPS
    supporting the PWG Raster input format which is required to
    be supported by IPP Everywhere printers, making a shared
    CUPS queue emulating an IPP Everywhere printer. This is a
    first implementation which supports the black, RGB, CMYK,
    sGray, sRGB, and Adobe RGB color spaces (all mapped to
    DeviceGray, DeviceRGB, and DeviceCMYK resp. in the PDF
    output) with 1, 8, and 16 bits per component color
    depth. sGray, sRGB, and Adobe RGB are currently also mapped
    to DeviceGray and DeviceRGB and do not have the correct
    color management yet, so color output is not absolutely
    correct. Note that mime.types of CUPS up to 1.7.2 has a bug
    which prevents PWG Raster to be recognized, the
    "priority(100)" of the rule needs to be changed to
    "priority(150)".
  * cups-browsed: Create local queues also to access classes on
    remote CUPS servers (Ubuntu bug #1313741).
  * cups-browsed: Let a newly discovered printer not only
    overtaking an existing printer entry if it is from the same
    host (usually IPP -> IPPS) or without host entry
    (unconfirmed local queue from previous cups-browsed session)
    but also if it is marked disappeared. So printer entries get
    correctly migrated when things like a host name change of
    the remote server happen.
  * cups-browsed: Always do case-insensitive comparing of
    strings, as CUPS queue names and URIs are case-insensitive
    (CUPS STR #4411).
  For details see the NEWS file.
* Mon Apr 28 2014 jsmeix@suse.de
- Version upgrade to 1.0.53
  Changes in 1.0.53:
  * foomatic-rip: Fixed segfault when creating log file, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1206
  * cups-browsed: SECURITY FIX: Fix on usage of the
    "BrowseAllow" directive in cups-browsed.conf. Before, if the
    argument of a "BrowseAllow" directive is not understood it
    is treated as the directive not having been there, allowing
    any host if this was the only "BrowseAllow" directive. Now
    we treat this as a directive which no host can fulfill, not
    allowing any host if it was the only one. No "BrowseAllow"
    directive means access for all, as before, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1204
    (CVE-2014-4338 bnc#883536 and bnc#871327 therein comment#23
    and subsequent comments).
  * cups-browsed: SECURITY FIX: Further improvement on the fix
    in 1.0.51 as it was insufficient. In addition, some fixes
    against OOB access are done (CVE-2014-4336 CVE-2014-4337
    bnc#883543 and bnc#871327 therein comment#30 and subsequent
    comments).
- Removed the "# BrowseAllow cups.example.com" example line in
  /etc/cups/cups-browsed.conf because hostnames do not work, see
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1205
* Thu Apr 24 2014 jsmeix@suse.de
- Split cups-browsed into a cups-filters-cups-browsed sub-package
  so that cups-browsed can be installed without all the other
  stuff from cups-filters (bnc#873204).
- Have libcupsfilters.so.* in the cups-filters-ghostscript
  sub-package because gstoraster is linked with libcupsfilters
  so that now cups-filters-foomatic-rip requires
  cups-filters-ghostscript which is still o.k. because
  cups-filters-ghostscript does not require cups-filters
  (cf. the entry dated "Thu Apr 10 10:22:25 CEST 2014" below).
- Do no longer rename installed /usr/share/cups/banners/* files
  and the installed /usr/share/cups/data/testprint
  (cf. the entry dated "Fri Aug 30 12:53:57 CEST 2013" below)
  because since CUPS 1.7.2 those files are no longer provided
  in our cups RPM package because since CUPS >= 1.6
  the CUPS banners and testprint do no longer work because
  there is no longer a filter for Linux that can convert
  the CUPS banner files. Since CUPS >= 1.6 only the banners
  and testprint in cups-filters work (bnc#873376).
  For CUPS <= 1.5.4 (where CUPS banners and testprint works)
  this does not make a difference because the cups-filters
  main package conflicts with CUPS <= 1.5.4.
* Thu Apr 10 2014 jsmeix@suse.de
- Have libcupsfilters.so.* in the cups-filters-foomatic-rip
  sub-package because foomatic-rip is linked with libcupsfilters
  so that it must be in the cups-filters-foomatic-rip sub-package
  to ensure the cups-filters-foomatic-rip sub-package can be
  installed on its own without a RPM requirement for the
  cups-filters main package which would cause conflicts
  with CUPS <= 1.5.4 in particular when building packages
  with CUPS <= 1.5.4 that have foomatic-rip as build requirement
  (e.g. hplip via "BuildRequires: foomatic-filters").
* Tue Apr  8 2014 jsmeix@suse.de
- Version upgrade to 1.0.52
  Changes in 1.0.52 (excerpt):
  * texttopdf, imagetopdf, imagetoraster:
    Range-check paper dimensions and margins taken
    from the PPD file and correct them if needed, see
    https://bugs.linuxfoundation.org/show_bug.cgi?id=1195
* Thu Apr  3 2014 jsmeix@suse.de
- Version upgrade to 1.0.51
  * cups-browsed: SECURITY FIX to prevent arbitrary code
    injection into the System V interface scripts generated for
    queues for discovered native IPP printers by a malicious IPP
    print service with forged make/model and/or PDL string
    (CVE-2014-2707 bnc#871327).
- Version upgrade to 1.0.50
  Changes in 1.0.50 (excerpt):
  * pdftops: Let old HP LaserJet printers (model number without
    letter, like "LaserJet 3" or "LaserJet 4000") use Poppler
    instead of Ghostscript.
  * pdftops: Improved workaround for Toshiba printers. Instead
    of using Poppler do not emit TrueType fonts with Ghostscript.
* Thu Mar 27 2014 jsmeix@suse.de
- Provide foomatic-filters with the exact foomatic-rip version
  that is included in cups-filters and conflict with any other
  foomatic-filters version (bnc#870621).
* Wed Mar 26 2014 jsmeix@suse.de
- Upgrade to current tarball cups-filters-1.0-20140326.tar.gz
  that is is version 1.0.49 plus the fix for
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1187
  "percent-encode component parts of the CUPS device-URI"
  see also (bnc#869692).
- Prepare spec files to build both releases and current tarballs
  easily in the future by using special different version strings.
* Tue Mar 25 2014 jsmeix@suse.de
- Version upgrade to 1.0.49
  Changes in 1.0.49 (excerpt):
  * pdftops: Fixed typo which always made PostScript level 2 being
    generated when using Poppler's pdftops.
  Changes in 1.0.48 (excerpt):
  * cups-browsed: Fix for a crash which happens on Bonjour reports
    of printers without "product", "usb_MDL", and "ty" fields
  Changes in 1.0.47 (excerpt):
  * pdftoopvp: SECURITY FIX for CVE-2013-6474, CVE-2013-6475,
    and CVE-2013-6476: Introductionof gmallocn and gmallocn3
    to protect against arbitrary code execution with the
    privileges of the "lp" user via malicious PDF files. Also
    restrict the directory from where OPVP drivers can get
    loaded.
  * urftopdf: SECURITY FIX for CVE-2013-6473: Two heap-based
    buffer overflow flaws in urftopdf. If a malicious URF file
    were processed it could lead to arbitrary code execution
    with the privileges of the "lp" user.
  * cups-browsed: Check for changes of the URI of a queue which
    we have created and correct the URI if needed
  Changes in 1.0.46 (excerpt):
  * gstoraster: Ignore SIGCHLD, rely on waitpid instead and
    fix two instances of insufficient EINTR handling.
  Changes in 1.0.45 (excerpt):
  * cups-browsed: Added auto-shutdown feature for on-demand use
    of cups-browsed (for example on mobile devices). With auto
    shutdown active, cups-browsed terminates after a certain
    time interval (30 sec by default) without having any remote
    printer to make available locally. The mode can be turned
    on, turned off (default) or set to automatically be off
    while avahi-daemon is running an on otherwise (controlled by
    avahi-daemon running on-demand). The mode and the timeout
    interval can be selected by command line options, the
    configuration file, and sending signals to cups-browsed
    (on/off only).
  * cups-browsed: To make Bonjour-discovered printers locally
    available avahi-daemon does not need to be started before
    cups-browsed and does not need to stay continuously running
    while cups-browsed is running. Bonjour-discovered printers
    are now added whenever avahi-daemon starts and removed
    whenever avahi-daemon stops and cups-browsed keeps running.
  * pdftops: Log command lines of renderer (Ghostscript, pdftops,
    pdftocairo, acroread) and of pstops in CUPS' error_log (in
    debug mode).
  Changes in 1.0.44 (excerpt):
  * README: Documented the "hybrid" choice for the PDF renderer
    in the pdftops filter.
  Changes in 1.0.43 (excerpt):
  * cups-browsed: When automatically setting up a PPD-less print
    queue for an IPP network printer add make/model info as an
    additional "make-and-model" command line option to the call
    of the pdftoippprinter filter, this way filters can do
    make/model-specific exceptions.
  * pdftops: Ignore "landscape", "orientation-requested",
    "fit-to-page", and any page geometry options. The first two
    do not make sense on PDF input and therefore should only be
    used in ...topdf filters used before pdftopdf, the others
    are already taken care of by pdftopdf so that pdftops gets
    pages with print-ready page geometry.
  * pdftopdf: If there is no PPD file or no
    "*LandscapeOrientation:" keyword in the PPD file, rotate
    counterclockwise, not clockwise to fit a landscape-oriented
    page on a portrait-oriented sheet.
  * pstopdf: Support for the "landscape" and
    "orientation-requested" options.
  * pdftops: After fixing the output of rotated PDF pages
    (usually landscape-oriented pages rotated by pdftopdf) in
    Poppler (Poppler/freedesktop.org bug #72312) corrected the
    use of "pdftops -origpagesizes" in pdftops appropriately.
  Changes in 1.0.42 (excerpt):
  * pdftoraster: Take into account rotate field in PDF header,
    when pdftopdf rotates a page to fit the paper it sets the
    rotate field and does not swap the width and height entries.
  * cups-browsed: Fixed several memory leaks by adding missing
    free() calls and removing an unneeded strdup().
  * foomatic-rip: Moved foomatic-rip's upstream home from the
    foomatic-filters package to cups-filters, to make it easier
    for distributions to ship and maintain a complete printing
    stack and also to make upstream maintenance and development
    easier.
  * foomatic-rip: Removed support for all the non-CUPS printing
    environments as they are discontinued upstream. Now
    foomatic-rip only works as a CUPS filter and in a
    spooler-less direct mode, where the latter is mainly
    for testing and debugging.
  Changes in 1.0.41 (excerpt):
  * cups-browsed: Added support for automatic PPD-less setup of
    print queues for IPP printers discovered on the network via
    Bonjour. Supported are printers with known languages (PWG
    Raster, PDF, PostScript, PCL XL, PCL 5c/e), especially also
    IPP Everywhere printers. This functionality is especially
    ment for mobile devices to be able to print without printer
    setup tool and without printer driver/PPD collection.
  * pdftoippprinter: New filter for PPD-less printing. The filter
    will be configured as System-V interface script for a print
    queue for a discovered IPP network printer generated by
    cups-browsed.
  * cups-browsed: Fixed socket leaks in recent IPP subscriptions
    changes.
- Since cups-filters version 1.0.42 foomatic-rip is also
  provided by cups-filters so that there is a file conflict
  with the foomatic-filters package (both provide
  /usr/lib/cups/filter/foomatic-rip and
  /usr/share/man/man1/foomatic-rip). Therefore foomatic-rip
  is separated in the sub-package cups-filters-foomatic-rip
  and only that sub-package conflicts with foomatic-filters.
* Thu Mar 13 2014 jsmeix@suse.de
- Added "Recommends: poppler-tools" because /usr/bin/pdftops
  (provided by poppler-tools) is needed (but not required
  for non-PostScript printers) to print PDFs on PostScript
  printers (bnc#868148).
* Thu Jan 30 2014 jsmeix@suse.de
- Moved /usr/lib/libcupsfilters.so /usr/lib/libcupsfilters.so
  /usr/lib/pkgconfig/libcupsfilters.pc /usr/include/fontembed/*
  /usr/lib/pkgconfig/libfontembed.pc /usr/include/cupsfilters/*
  to the cups-filters-devel sub-package to fix rpmlint
  "devel-file-in-non-devel-package" errors.
* Fri Jan 10 2014 jsmeix@suse.de
- Split /usr/share/cups/ppdc/escp.h and /usr/share/cups/ppdc/pcl.h
  into a cups-filters-devel sub-package and let cups-filters-devel
  conflict with cups-devel < 1.6. because up to CUPS 1.5.4
  those files are provided by the cups-devel package
  (see the next entry below).
* Thu Jan  9 2014 jsmeix@suse.de
- Conflict with CUPS < 1.6 because up to CUPS 1.5.4
  the following files are provided by the cups binary RPM package
  /usr/lib/cups/filter/commandtoescpx
  /usr/lib/cups/filter/commandtopclx
  /usr/lib/cups/filter/imagetops
  /usr/lib/cups/filter/imagetoraster
  /usr/lib/cups/filter/pdftops
  /usr/lib/cups/filter/rastertoescpx
  /usr/lib/cups/filter/rastertopclx
  /usr/lib/cups/filter/texttops
  /usr/lib/cups/backend/parallel
  /usr/lib/cups/backend/serial
  and the following files are provided by the cups-devel package
  /usr/share/cups/ppdc/escp.h
  /usr/share/cups/ppdc/pcl.h
* Thu Dec 19 2013 jsmeix@suse.de
- Split binary RPM sub-package cups-filters-ghostscript
  which is needed for Ghostscript version upgrade to 9.10.
  Since Ghostscript version 9.10 the CUPS filters
  gstoraster and gstopxl are removed from Ghostscript.
  Those filters are now provided by cups-filters.
  The binary RPM sub-package cups-filters-ghostscript
  provides only those CUPS filters for Ghostscript.
  This way cups-filters-ghostscript can be used
  with the traditional CUPS up to version 1.5.4
  where the other filters, backends, and cups-browsed
  from cups-filters would cause conflicts because
  CUPS <= 1.5.4 already provides them. In contrast
  for CUPS versions since 1.6 the whole cups-filters
  is usually needed (but not strictly required).
* Wed Oct 30 2013 jsmeix@suse.de
- Version upgrade to 1.0.40
  Changes in 1.0.40 (excerpt):
  * pdftops: Introduced new "hybrid" renderer: Here usually
    Ghostscript is used, but if the printer is a Brother,
    Minolta, or Konica Minolta Poppler's pdftops gets used. This
    is a quirk rule to work around bugs in the PS interpreters
    of the printers.
  Changes in 1.0.39 (excerpt):
  * pdftops: Fix for landscape PDF handling.
  Changes in 1.0.38 (excerpt):
  * pdftops: Added "-dNOINTERPOLATE" to the Ghostscript command
    line for quicker processing of embedded bitmaps.
  * pstopdf: Added "-dUseCIEColor" to the Ghostscript command
    line to assure compatibility with newer Ghostscript
    versions (9.08 and newer).
  Changes in 1.0.37 (excerpt):
  * Added example configuration files for systemd and Upstart, see
    https://bugzilla.novell.com/show_bug.cgi?id=735404#c46
    (obsoletes cups-browsed.service).
  * Build system: Make sure that gstoraster gets linked against
    the libcupsfilters of the currently built package and not
    of the system (obsoletes broken-autotools.patch).
  * cupsfilters.convs: Reworked the cost factors of the filters
    to avoid bogus filter chains like pstotiff|imagetopdf
    instead of pstopdf|pdftopdf for PostScript->PDF, see
    https://bugzilla.novell.com/show_bug.cgi?id=735404#c53
  * cups-browsed: Fixed building with CUPS 1.5.x and older,
    ippSetVersion() was missing under the accessor function
    definitions for backward compatibility
    (obsoletes cups-15-compat.patch).
  For details see the NEWS and README files.
- cups-browsed.service is obsolete (provided in upstream sources).
- broken-autotools.patch is obsolete (fixed in upstream sources).
- cups-15-compat.patch is obsolete (fixed in upstream sources).
* Fri Aug 30 2013 jsmeix@suse.de
- Rename installed /usr/share/cups/banners/* files
  and the installed /usr/share/cups/data/testprint
  because those files are also provided by CUPS
  but CUPS provides them in a different format and
  I not want to overwrite CUPS files but I do not like
  to delete the cups-filters version of those files
  instead I like to provide them at least for now as well
  so that we could evaluate which ones we may use finally.
* Wed Aug 21 2013 tchvatal@suse.com
- Version bump to 1.0.36:
  * new manpages
  * many small adjustments see NEWS
- Remove obsolete patch fix_cups-browsed_init_script.patch
- Remove obsolete patch BZR_revision_7085_7084.diff
- Add new patch to compat with old cups cups-15-compat.patch
- Add new patch to fix borked autotools broken-autotools.patch
- Adjust the service call for older distros it was in /sbin
- Enable tests
* Fri Aug  2 2013 jsmeix@suse.de
- Added support for systemd (mainly done by tchvatal@suse.com).
  cups-browsed.service is openSUSE's systemd unit file.
  Nevertheless a traditional SysVInit script
  /etc/init.d/cups-browsed is still available.
* Tue Jul 30 2013 jsmeix@suse.de
- BZR_revision_7085_7084.diff makes the code working
  with Poppler >= 0.23.x see
  https://bugs.linuxfoundation.org/show_bug.cgi?id=1144
- Version upgrade to cups-filters-1.0.35
  that provides in particular various bugfixes,
  for details see the NEWS and README files.
* Fri Apr 19 2013 jsmeix@suse.de
- Version upgrade to cups-filters-1.0.34
  that provides in particular various enhancements for
  cups-browsed, for details see the NEWS and README files.
* Wed Mar 13 2013 jsmeix@suse.de
- Version upgrade to cups-filters-1.0.30
- cups-filters-1.0.30 does no longer build for openSUSE 12.1
  because configure requests 'glib-2.0 >= 2.30.2' but
  version of GLib in openSUSE 12.1 is 2.30.1.
* Fri Jan  4 2013 jsmeix@suse.de
- Version upgrade to cups-filters-1.0.29
  that adds cups-browsed.
- fix_cups-browsed_init_script.patch
  adds LSB header line to cups-browsed init script
  otherwise the openSUSE brp-55-boot-scripts aborts build
  with "ERROR: found one or more broken init or boot scripts"
  and this patch changes "$avahi-daemon $cups" to "avahi cupsd"
  because there is no $avahi-daemon $cups in /etc/insserv.conf
  but /etc/init.d/avahi-daemon "Provides: avahi"
  and /etc/init.d/cups "Provides: cupsd"
  otherwise RPMLINT reports "init-script-undefined-dependency"
  and this patch removes runlevel 4 from Default-Start
  otherwise RPMLINT reports "init-script-runlevel-4".
* Fri Jan  4 2013 mmeister@suse.com
- Adapted and simplified spec file to make it build.
* Wed Oct 17 2012 p.drouand@gmail.com
- Initial release
